@@ -6,7 +6,7 @@ use Carp;
 require Class::Accessor;
 use base qw(Class::Accessor);
 
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 __PACKAGE__->mk_accessors(qw(_datasource _namespace));
 
@@ -22,6 +22,8 @@ ABSTRACT CLASS
 
 please see L<Class::DBI::Loader>
 
+=head2 METHODS
+
 =cut
 
 sub new {
@@ -44,16 +46,40 @@ sub new {
     $self;
 }
 
+=head3 find_class
+
+Returns a tables class.
+
+    my $class = $loader->find_class($table);
+
+=cut
+
 sub find_class {
     my ( $self, $table ) = @_;
     return $self->{CLASSES}->{$table};
 }
 
+=head3 classes
+
+Returns a sorted list of classes.
+
+    my $@classes = $loader->classes;
+
+=cut
+
 sub classes {
     my $self = shift;
     return sort values %{ $self->{CLASSES} };
 }
 
+=head3 tables
+
+Returns a sorted list of tables.
+
+    my @tables = $loader->tables;
+
+=cut
+
 sub tables {
     my $self = shift;
     return sort keys %{ $self->{CLASSES} };
